@@ -32,6 +32,7 @@ from giscanner.dumper import compile_introspection_binary
 from giscanner.glibtransformer import GLibTransformer, IntrospectionBinary
 from giscanner.minixpath import myxpath, xpath_assert
 from giscanner.sourcescanner import SourceScanner
+from giscanner.shlibs import resolve_shlibs
 from giscanner.transformer import Transformer
 
 def _get_option_parser():
@@ -80,6 +81,9 @@ def _get_option_parser():
     parser.add_option("", "--pkg",
                       action="append", dest="packages", default=[],
                       help="pkg-config packages to get cflags from")
+    parser.add_option("", "--pkg-export",
+                      action="append", dest="packages_export", default=[],
+                      help="Associated pkg-config packages for this library")
     parser.add_option("-v", "--verbose",
                       action="store_true", dest="verbose",
                       help="be verbose")
@@ -246,20 +250,6 @@ def scanner_main(args):
         _error("Must specify --program or --library")
     libraries = options.libraries
 
-    # FIXME: using LPATH is definitely not portable enough. Using Python's
-    # find_library for finding our shared libraries is not a portable enough
-    # anyway as it behaves differently depending on the OS
-    lpath = os.environ.get('LPATH')
-    library_path = ':'.join(options.library_paths)
-
-    ld_library_path = os.environ.get('LD_LIBRARY_PATH')
-    if ld_library_path:
-        library_path = ':'.join([ld_library_path, library_path])
-
-    if lpath:
-        os.environ['LPATH'] = ':'.join([lpath, library_path])
-    else:
-        os.environ['LPATH'] = library_path
     filenames = []
     for arg in args:
         if (arg.endswith('.c') or
@@ -319,6 +309,8 @@ def scanner_main(args):
         binary = compile_introspection_binary(options,
                             glibtransformer.get_get_type_functions())
 
+    shlibs = resolve_shlibs(options, binary, libraries)
+
     glibtransformer.set_introspection_binary(binary)
 
     namespace = glibtransformer.parse()
@@ -330,8 +322,12 @@ def scanner_main(args):
         raise SystemExit("ERROR in annotation: %s" % (str(e), ))
 
     # Write out AST
-    writer = Writer(namespace, libraries, transformer.get_includes(),
-                    options.packages, options.c_includes,
+    if options.packages_export:
+        exported_packages = options.packages_export
+    else:
+        exported_packages = options.packages
+    writer = Writer(namespace, shlibs, transformer.get_includes(),
+                    exported_packages, options.c_includes,
                     transformer.get_strip_prefix())
     data = writer.get_xml()
     if options.output:
