@@ -19,6 +19,9 @@ struct _TestDrawableClass
 GType test_drawable_get_type (void) G_GNUC_CONST;
 
 void test_drawable_do_foo (TestDrawable *drawable, int x);
+void test_drawable_get_origin (TestDrawable *drawable, int *x, int *y);
+void test_drawable_get_size (TestDrawable *drawable, guint *width, guint *height);
+void test_drawable_do_foo_maybe_throw (TestDrawable *drawable, int x, GError **error);
 
 struct _TestPixmapObjectClass
 {
